
<!---
FrozenIsBool True
-->

##Example

And we can reset at the same time several Mro attributes.
Also here we show that there is the option DefaultMutableBool to directly init the mutables variables.
